@@ -71,14 +71,14 @@ class TransferClient:
     def create_server(
         self,
         Certificate: str = None,
-        EndpointDetails: EndpointDetailsTypeDef = None,
+        EndpointDetails: "EndpointDetailsTypeDef" = None,
         EndpointType: Literal["PUBLIC", "VPC", "VPC_ENDPOINT"] = None,
         HostKey: str = None,
-        IdentityProviderDetails: IdentityProviderDetailsTypeDef = None,
+        IdentityProviderDetails: "IdentityProviderDetailsTypeDef" = None,
         IdentityProviderType: Literal["SERVICE_MANAGED", "API_GATEWAY"] = None,
         LoggingRole: str = None,
         Protocols: List[Literal["SFTP", "FTP", "FTPS"]] = None,
-        Tags: List[TagTypeDef] = None,
+        Tags: List["TagTypeDef"] = None,
     ) -> CreateServerResponseTypeDef:
         """
         [Client.create_server documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/transfer.html#Transfer.Client.create_server)
@@ -91,10 +91,10 @@ class TransferClient:
         UserName: str,
         HomeDirectory: str = None,
         HomeDirectoryType: Literal["PATH", "LOGICAL"] = None,
-        HomeDirectoryMappings: List[HomeDirectoryMapEntryTypeDef] = None,
+        HomeDirectoryMappings: List["HomeDirectoryMapEntryTypeDef"] = None,
         Policy: str = None,
         SshPublicKeyBody: str = None,
-        Tags: List[TagTypeDef] = None,
+        Tags: List["TagTypeDef"] = None,
     ) -> CreateUserResponseTypeDef:
         """
         [Client.create_user documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/transfer.html#Transfer.Client.create_user)
@@ -174,7 +174,7 @@ class TransferClient:
         [Client.stop_server documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/transfer.html#Transfer.Client.stop_server)
         """
 
-    def tag_resource(self, Arn: str, Tags: List[TagTypeDef]) -> None:
+    def tag_resource(self, Arn: str, Tags: List["TagTypeDef"]) -> None:
         """
         [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/transfer.html#Transfer.Client.tag_resource)
         """
@@ -199,10 +199,10 @@ class TransferClient:
         self,
         ServerId: str,
         Certificate: str = None,
-        EndpointDetails: EndpointDetailsTypeDef = None,
+        EndpointDetails: "EndpointDetailsTypeDef" = None,
         EndpointType: Literal["PUBLIC", "VPC", "VPC_ENDPOINT"] = None,
         HostKey: str = None,
-        IdentityProviderDetails: IdentityProviderDetailsTypeDef = None,
+        IdentityProviderDetails: "IdentityProviderDetailsTypeDef" = None,
         LoggingRole: str = None,
         Protocols: List[Literal["SFTP", "FTP", "FTPS"]] = None,
     ) -> UpdateServerResponseTypeDef:
@@ -216,7 +216,7 @@ class TransferClient:
         UserName: str,
         HomeDirectory: str = None,
         HomeDirectoryType: Literal["PATH", "LOGICAL"] = None,
-        HomeDirectoryMappings: List[HomeDirectoryMapEntryTypeDef] = None,
+        HomeDirectoryMappings: List["HomeDirectoryMapEntryTypeDef"] = None,
         Policy: str = None,
         Role: str = None,
     ) -> UpdateUserResponseTypeDef:
