@@ -3,9 +3,9 @@ Main interface for transfer service type definitions.
 
 Usage::
 
-    from mypy_boto3.transfer.type_defs import CreateServerResponseTypeDef
+    from mypy_boto3.transfer.type_defs import DescribedServerTypeDef
 
-    data: CreateServerResponseTypeDef = {...}
+    data: DescribedServerTypeDef = {...}
 """
 from datetime import datetime
 import sys
@@ -22,22 +22,22 @@ else:
 
 
 __all__ = (
+    "DescribedServerTypeDef",
+    "DescribedUserTypeDef",
+    "EndpointDetailsTypeDef",
+    "HomeDirectoryMapEntryTypeDef",
+    "IdentityProviderDetailsTypeDef",
+    "ListedServerTypeDef",
+    "ListedUserTypeDef",
+    "SshPublicKeyTypeDef",
+    "TagTypeDef",
     "CreateServerResponseTypeDef",
     "CreateUserResponseTypeDef",
-    "EndpointDetailsTypeDef",
-    "IdentityProviderDetailsTypeDef",
-    "TagTypeDef",
-    "DescribedServerTypeDef",
     "DescribeServerResponseTypeDef",
-    "HomeDirectoryMapEntryTypeDef",
-    "SshPublicKeyTypeDef",
-    "DescribedUserTypeDef",
     "DescribeUserResponseTypeDef",
     "ImportSshPublicKeyResponseTypeDef",
-    "ListedServerTypeDef",
     "ListServersResponseTypeDef",
     "ListTagsForResourceResponseTypeDef",
-    "ListedUserTypeDef",
     "ListUsersResponseTypeDef",
     "PaginatorConfigTypeDef",
     "TestIdentityProviderResponseTypeDef",
@@ -45,33 +45,15 @@ __all__ = (
     "UpdateUserResponseTypeDef",
 )
 
-CreateServerResponseTypeDef = TypedDict("CreateServerResponseTypeDef", {"ServerId": str})
-
-CreateUserResponseTypeDef = TypedDict(
-    "CreateUserResponseTypeDef", {"ServerId": str, "UserName": str}
-)
-
-EndpointDetailsTypeDef = TypedDict(
-    "EndpointDetailsTypeDef",
-    {"AddressAllocationIds": List[str], "SubnetIds": List[str], "VpcEndpointId": str, "VpcId": str},
-    total=False,
-)
-
-IdentityProviderDetailsTypeDef = TypedDict(
-    "IdentityProviderDetailsTypeDef", {"Url": str, "InvocationRole": str}, total=False
-)
-
-TagTypeDef = TypedDict("TagTypeDef", {"Key": str, "Value": str})
-
 _RequiredDescribedServerTypeDef = TypedDict("_RequiredDescribedServerTypeDef", {"Arn": str})
 _OptionalDescribedServerTypeDef = TypedDict(
     "_OptionalDescribedServerTypeDef",
     {
         "Certificate": str,
-        "EndpointDetails": EndpointDetailsTypeDef,
+        "EndpointDetails": "EndpointDetailsTypeDef",
         "EndpointType": Literal["PUBLIC", "VPC", "VPC_ENDPOINT"],
         "HostKeyFingerprint": str,
-        "IdentityProviderDetails": IdentityProviderDetailsTypeDef,
+        "IdentityProviderDetails": "IdentityProviderDetailsTypeDef",
         "IdentityProviderType": Literal["SERVICE_MANAGED", "API_GATEWAY"],
         "LoggingRole": str,
         "Protocols": List[Literal["SFTP", "FTP", "FTPS"]],
@@ -79,7 +61,7 @@ _OptionalDescribedServerTypeDef = TypedDict(
         "State": Literal[
             "OFFLINE", "ONLINE", "STARTING", "STOPPING", "START_FAILED", "STOP_FAILED"
         ],
-        "Tags": List[TagTypeDef],
+        "Tags": List["TagTypeDef"],
         "UserCount": int,
     },
     total=False,
@@ -90,30 +72,17 @@ class DescribedServerTypeDef(_RequiredDescribedServerTypeDef, _OptionalDescribed
     pass
 
 
-DescribeServerResponseTypeDef = TypedDict(
-    "DescribeServerResponseTypeDef", {"Server": DescribedServerTypeDef}
-)
-
-HomeDirectoryMapEntryTypeDef = TypedDict(
-    "HomeDirectoryMapEntryTypeDef", {"Entry": str, "Target": str}
-)
-
-SshPublicKeyTypeDef = TypedDict(
-    "SshPublicKeyTypeDef",
-    {"DateImported": datetime, "SshPublicKeyBody": str, "SshPublicKeyId": str},
-)
-
 _RequiredDescribedUserTypeDef = TypedDict("_RequiredDescribedUserTypeDef", {"Arn": str})
 _OptionalDescribedUserTypeDef = TypedDict(
     "_OptionalDescribedUserTypeDef",
     {
         "HomeDirectory": str,
-        "HomeDirectoryMappings": List[HomeDirectoryMapEntryTypeDef],
+        "HomeDirectoryMappings": List["HomeDirectoryMapEntryTypeDef"],
         "HomeDirectoryType": Literal["PATH", "LOGICAL"],
         "Policy": str,
         "Role": str,
-        "SshPublicKeys": List[SshPublicKeyTypeDef],
-        "Tags": List[TagTypeDef],
+        "SshPublicKeys": List["SshPublicKeyTypeDef"],
+        "Tags": List["TagTypeDef"],
         "UserName": str,
     },
     total=False,
@@ -124,12 +93,18 @@ class DescribedUserTypeDef(_RequiredDescribedUserTypeDef, _OptionalDescribedUser
     pass
 
 
-DescribeUserResponseTypeDef = TypedDict(
-    "DescribeUserResponseTypeDef", {"ServerId": str, "User": DescribedUserTypeDef}
+EndpointDetailsTypeDef = TypedDict(
+    "EndpointDetailsTypeDef",
+    {"AddressAllocationIds": List[str], "SubnetIds": List[str], "VpcEndpointId": str, "VpcId": str},
+    total=False,
 )
 
-ImportSshPublicKeyResponseTypeDef = TypedDict(
-    "ImportSshPublicKeyResponseTypeDef", {"ServerId": str, "SshPublicKeyId": str, "UserName": str}
+HomeDirectoryMapEntryTypeDef = TypedDict(
+    "HomeDirectoryMapEntryTypeDef", {"Entry": str, "Target": str}
+)
+
+IdentityProviderDetailsTypeDef = TypedDict(
+    "IdentityProviderDetailsTypeDef", {"Url": str, "InvocationRole": str}, total=False
 )
 
 _RequiredListedServerTypeDef = TypedDict("_RequiredListedServerTypeDef", {"Arn": str})
@@ -153,26 +128,6 @@ class ListedServerTypeDef(_RequiredListedServerTypeDef, _OptionalListedServerTyp
     pass
 
 
-_RequiredListServersResponseTypeDef = TypedDict(
-    "_RequiredListServersResponseTypeDef", {"Servers": List[ListedServerTypeDef]}
-)
-_OptionalListServersResponseTypeDef = TypedDict(
-    "_OptionalListServersResponseTypeDef", {"NextToken": str}, total=False
-)
-
-
-class ListServersResponseTypeDef(
-    _RequiredListServersResponseTypeDef, _OptionalListServersResponseTypeDef
-):
-    pass
-
-
-ListTagsForResourceResponseTypeDef = TypedDict(
-    "ListTagsForResourceResponseTypeDef",
-    {"Arn": str, "NextToken": str, "Tags": List[TagTypeDef]},
-    total=False,
-)
-
 _RequiredListedUserTypeDef = TypedDict("_RequiredListedUserTypeDef", {"Arn": str})
 _OptionalListedUserTypeDef = TypedDict(
     "_OptionalListedUserTypeDef",
@@ -191,8 +146,53 @@ class ListedUserTypeDef(_RequiredListedUserTypeDef, _OptionalListedUserTypeDef):
     pass
 
 
+SshPublicKeyTypeDef = TypedDict(
+    "SshPublicKeyTypeDef",
+    {"DateImported": datetime, "SshPublicKeyBody": str, "SshPublicKeyId": str},
+)
+
+TagTypeDef = TypedDict("TagTypeDef", {"Key": str, "Value": str})
+
+CreateServerResponseTypeDef = TypedDict("CreateServerResponseTypeDef", {"ServerId": str})
+
+CreateUserResponseTypeDef = TypedDict(
+    "CreateUserResponseTypeDef", {"ServerId": str, "UserName": str}
+)
+
+DescribeServerResponseTypeDef = TypedDict(
+    "DescribeServerResponseTypeDef", {"Server": "DescribedServerTypeDef"}
+)
+
+DescribeUserResponseTypeDef = TypedDict(
+    "DescribeUserResponseTypeDef", {"ServerId": str, "User": "DescribedUserTypeDef"}
+)
+
+ImportSshPublicKeyResponseTypeDef = TypedDict(
+    "ImportSshPublicKeyResponseTypeDef", {"ServerId": str, "SshPublicKeyId": str, "UserName": str}
+)
+
+_RequiredListServersResponseTypeDef = TypedDict(
+    "_RequiredListServersResponseTypeDef", {"Servers": List["ListedServerTypeDef"]}
+)
+_OptionalListServersResponseTypeDef = TypedDict(
+    "_OptionalListServersResponseTypeDef", {"NextToken": str}, total=False
+)
+
+
+class ListServersResponseTypeDef(
+    _RequiredListServersResponseTypeDef, _OptionalListServersResponseTypeDef
+):
+    pass
+
+
+ListTagsForResourceResponseTypeDef = TypedDict(
+    "ListTagsForResourceResponseTypeDef",
+    {"Arn": str, "NextToken": str, "Tags": List["TagTypeDef"]},
+    total=False,
+)
+
 _RequiredListUsersResponseTypeDef = TypedDict(
-    "_RequiredListUsersResponseTypeDef", {"ServerId": str, "Users": List[ListedUserTypeDef]}
+    "_RequiredListUsersResponseTypeDef", {"ServerId": str, "Users": List["ListedUserTypeDef"]}
 )
 _OptionalListUsersResponseTypeDef = TypedDict(
     "_OptionalListUsersResponseTypeDef", {"NextToken": str}, total=False
